package com.ittim.admin.controller.security;

import com.baomidou.mybatisplus.extension.api.R;
import com.ittim.common.bean.RedisKeys;
import com.ittim.common.enums.Status;
import com.wf.captcha.SpecCaptcha;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.wf.jwtp.provider.Token;
import org.wf.jwtp.provider.TokenStore;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import java.util.concurrent.TimeUnit;

/**
 * @author zzj
 * @Description TODO
 * @date 2020/9/30
 */
@RestController
@Api(tags = "登录模块")
@RequestMapping("/auth")
public class LoginController {

    @Resource(name = "zeroRedisTemplate")
    private RedisTemplate<String, Object> zeroRedisTemplate;

    private final TokenStore tokenStore;

    public LoginController(@Qualifier("jdbcTokenStore") TokenStore tokenStore) {
        this.tokenStore = tokenStore;
    }

    /**
     * 获取验证码
     *
     * @return 验证码Key 与 图片信息
     */
    @RequestMapping("/captcha")
    @ApiOperation(value = "获取验证码", notes = "获取验证码(验证码Key 与 图片信息)")
    public R<Map<String, String>> captcha() {
        SpecCaptcha specCaptcha = new SpecCaptcha(130, 48, 5);
        String verCode = specCaptcha.text().toLowerCase();
        // 存入redis并设置过期时间为30分钟
        zeroRedisTemplate.opsForValue().set(RedisKeys.CAPTCHA_KEY, verCode, 30, TimeUnit.MINUTES);
        // 将key和base64返回给前端
        Map<String, String> resultMap = new HashMap<>(16);
        resultMap.put("key", RedisKeys.CAPTCHA_KEY);
        resultMap.put("image", specCaptcha.toBase64());
        return R.ok(resultMap);
    }

    /**
     * 用户登录
     *
     * @param username 用户名
     * @param password 密码
     * @param verCode  验证码
     * @param verKey   验证码Key
     * @return 返回登录状态
     */
    @PostMapping("/login")
    @ApiOperation(value = "用户登录", notes = "用户登录(登录状态)")
    public R<Object> login(String username, String password, String verCode, String verKey) {
        // 获取redis中的验证码
        String redisCode = (String) zeroRedisTemplate.opsForValue().get(RedisKeys.CAPTCHA_KEY);
        // 判断验证码
        if (verCode == null || !Objects.equals(redisCode, verCode.trim().toLowerCase())) {
            return R.restResult("验证码不正确", Status.CAPTCHA_INCORRECT);
        }

        //未完成
        // 签发token
//        Token token = tokenStore.createNewToken(userId, permissions, roles, 60 * 60 * 24 * 30);

        //返回访问令牌Token
        Map<String, String> resultMap = new HashMap<>(16);
//        String accessToken = token.getAccessToken();
//        resultMap.put("access_token", accessToken);
        return R.restResult(resultMap, Status.LOGIN);
    }

    /**
     * 更新Token
     *
     * @param refreshToken 旧Token
     * @return 新Token
     */
    @PostMapping("/token/refresh")
    @ApiOperation(value = "更新Token", notes = "更新Token(新Token)")
    public R<String> login(String refreshToken) {
        Token token = tokenStore.refreshToken(refreshToken);
        System.out.println("access_token：" + token.getAccessToken());
        return R.ok(token.getAccessToken());
    }

}
